.. toctree::
   :maxdepth: 2

Digest of qci_partner
=====================


+----------------------+------------------------------------+-------------------+----------------------------+
| id                   | name                               | side              | icq                        |
+----------------------+------------------------------------+-------------------+----------------------------+
| z0bug.res_partner_1  | Prima Distribuzione S.p.A.         | customer/supplier | icq_0002 icq_0006 icq_pa11 |
+----------------------+------------------------------------+-------------------+----------------------------+
| z0bug.res_partner_10 | Notaio Libero Jackson              | supplier          |                            |
+----------------------+------------------------------------+-------------------+----------------------------+
| z0bug.res_partner_11 | Nebula Caffè S.p.A.                | supplier          |                            |
+----------------------+------------------------------------+-------------------+----------------------------+
| z0bug.res_partner_12 | Freie Universität Berlin           | supplier          |                            |
+----------------------+------------------------------------+-------------------+----------------------------+
| z0bug.res_partner_13 | Axelor GmbH                        | customer          | icq_pa12                   |
+----------------------+------------------------------------+-------------------+----------------------------+
| z0bug.res_partner_14 | SS Carrefur                        | supplier          |                            |
+----------------------+------------------------------------+-------------------+----------------------------+
| z0bug.res_partner_15 | Ente Porto                         | customer          | icq_0002 icq_pa14 icq_pa16 |
+----------------------+------------------------------------+-------------------+----------------------------+
| z0bug.res_partner_16 | Viking Office Depot Italia s.r.l.  | customer/supplier |                            |
+----------------------+------------------------------------+-------------------+----------------------------+
| z0bug.res_partner_17 | Vexor BV                           | supplier          |                            |
+----------------------+------------------------------------+-------------------+----------------------------+
| z0bug.res_partner_2  | Agro Latte Due  s.n.c.             | customer          | icq_0002 icq_0007          |
+----------------------+------------------------------------+-------------------+----------------------------+
| z0bug.res_partner_3  | Import Export Trifoglio s.r.l.     | customer          | icq_0001 icq_0006          |
+----------------------+------------------------------------+-------------------+----------------------------+
| z0bug.res_partner_4  | Delta 4 s.r.l.                     | supplier          |                            |
+----------------------+------------------------------------+-------------------+----------------------------+
| z0bug.res_partner_5  | Five Stars Hotel                   | supplier          |                            |
+----------------------+------------------------------------+-------------------+----------------------------+
| z0bug.res_partner_6  | Esa Electronic S.p.A               | customer          | icq_0003                   |
+----------------------+------------------------------------+-------------------+----------------------------+
| z0bug.res_partner_7  | Università della Svizzera Italiana | customer          | icq_pa13                   |
+----------------------+------------------------------------+-------------------+----------------------------+
| z0bug.res_partner_8  | Global Solution s.r.l.             | customer          | icq_pa15                   |
+----------------------+------------------------------------+-------------------+----------------------------+
| z0bug.res_partner_9  | Mario Rossi                        | customer          |                            |
+----------------------+------------------------------------+-------------------+----------------------------+

|
|

.. |Maturity| image:: https://img.shields.io/badge/maturity-Beta-yellow.png
    :target: https://odoo-community.org/page/development-status
    :alt: 
.. |license gpl| image:: https://img.shields.io/badge/licence-AGPL--3-blue.svg
    :target: http://www.gnu.org/licenses/agpl-3.0-standalone.html
    :alt: License: AGPL-3
.. |license opl| image:: https://img.shields.io/badge/licence-OPL-7379c3.svg
    :target: https://www.odoo.com/documentation/user/9.0/legal/licenses/licenses.html
    :alt: License: OPL
.. |Tech Doc| image:: https://www.zeroincombenze.it/wp-content/uploads/ci-ct/prd/button-docs-2.svg
    :target: https://wiki.zeroincombenze.org/en/Odoo/2.0.23/dev
    :alt: Technical Documentation
.. |Help| image:: https://www.zeroincombenze.it/wp-content/uploads/ci-ct/prd/button-help-2.svg
    :target: https://wiki.zeroincombenze.org/it/Odoo/2.0.23/man
    :alt: Technical Documentation
.. |Try Me| image:: https://www.zeroincombenze.it/wp-content/uploads/ci-ct/prd/button-try-it-2.svg
    :target: https://erp2.zeroincombenze.it
    :alt: Try Me
.. |Zeroincombenze| image:: https://avatars0.githubusercontent.com/u/6972555?s=460&v=4
   :target: https://www.zeroincombenze.it/
   :alt: Zeroincombenze
.. |en| image:: https://raw.githubusercontent.com/zeroincombenze/grymb/master/flags/en_US.png
   :target: https://www.facebook.com/Zeroincombenze-Software-gestionale-online-249494305219415/
.. |it| image:: https://raw.githubusercontent.com/zeroincombenze/grymb/master/flags/it_IT.png
   :target: https://www.facebook.com/Zeroincombenze-Software-gestionale-online-249494305219415/
.. |check| image:: https://raw.githubusercontent.com/zeroincombenze/grymb/master/awesome/check.png
.. |no_check| image:: https://raw.githubusercontent.com/zeroincombenze/grymb/master/awesome/no_check.png
.. |menu| image:: https://raw.githubusercontent.com/zeroincombenze/grymb/master/awesome/menu.png
.. |right_do| image:: https://raw.githubusercontent.com/zeroincombenze/grymb/master/awesome/right_do.png
.. |exclamation| image:: https://raw.githubusercontent.com/zeroincombenze/grymb/master/awesome/exclamation.png
.. |warning| image:: https://raw.githubusercontent.com/zeroincombenze/grymb/master/awesome/warning.png
.. |same| image:: https://raw.githubusercontent.com/zeroincombenze/grymb/master/awesome/same.png
.. |late| image:: https://raw.githubusercontent.com/zeroincombenze/grymb/master/awesome/late.png
.. |halt| image:: https://raw.githubusercontent.com/zeroincombenze/grymb/master/awesome/halt.png
.. |info| image:: https://raw.githubusercontent.com/zeroincombenze/grymb/master/awesome/info.png
.. |xml_schema| image:: https://raw.githubusercontent.com/zeroincombenze/grymb/master/certificates/iso/icons/xml-schema.png
   :target: https://github.com/zeroincombenze/grymb/blob/master/certificates/iso/scope/xml-schema.md
.. |DesktopTelematico| image:: https://raw.githubusercontent.com/zeroincombenze/grymb/master/certificates/ade/icons/DesktopTelematico.png
   :target: https://github.com/zeroincombenze/grymb/blob/master/certificates/ade/scope/Desktoptelematico.md
.. |FatturaPA| image:: https://raw.githubusercontent.com/zeroincombenze/grymb/master/certificates/ade/icons/fatturapa.png
   :target: https://github.com/zeroincombenze/grymb/blob/master/certificates/ade/scope/fatturapa.md
.. |chat_with_us| image:: https://www.shs-av.com/wp-content/chat_with_us.gif
   :target: https://t.me/Assitenza_clienti_powERP
